@@ -1,6 +1,7 @@
 from typing import Optional, Union, List
 
-from quickstats.components import AbstractObject, ExtendedModel, ExtendedMinimizer
+from quickstats import AbstractObject
+from quickstats.components import ExtendedModel, ExtendedMinimizer
 from quickstats.components.basics import WSArgument
 from quickstats.utils.common_utils import get_class_that_defined_method
 from quickstats.interface.root import RooArgSet
