@@ -10,7 +10,7 @@ import numpy as np
 import ROOT
 
 import quickstats
-from quickstats.components import AbstractObject
+from quickstats import AbstractObject
 
 class ExtendedMinimizer(AbstractObject):
     _SCAN_EXCLUDE_CONFIG_ = ['scan', 'minos', 'save']
