@@ -538,8 +538,11 @@ class ExtendedModel(AbstractObject):
         if pdf is None:
             pdf = self.pdf
         all_constraints = ROOT.RooArgSet()
-        cache_name = "CACHE_CONSTR_OF_PDF_{}_FOR_OBS_{}".format(self.pdf.GetName(), 
-                     ROOT.RooNameSet(self.data.get()).content())                 
+        if self.data is not None:
+            cache_name = "CACHE_CONSTR_OF_PDF_{}_FOR_OBS_{}".format(self.pdf.GetName(), 
+                         ROOT.RooNameSet(self.data.get()).content())
+        else:
+            cache_name = ""
         constr_cache = self.workspace.set(cache_name)
         if constr_cache and cache:
             # retrieve constrains from cache     
@@ -643,8 +646,8 @@ class ExtendedModel(AbstractObject):
             if (blind_max <= blind_min) or (blind_max > obs_max) or (blind_min < obs_min):
                 raise ValueError(f"invalid blinding range provided: min={blind_min}, max={blind_max}")
             _range_name_SBLo  = f"{range_name_SBLo}_{category}"
-            _range_name_Blind = f"{_range_name_Blind}_{category}"
-            _range_name_SBHi  = f"{_range_name_SBHi}_{category}"            
+            _range_name_Blind = f"{range_name_Blind}_{category}"
+            _range_name_SBHi  = f"{range_name_SBHi}_{category}"            
             obs.setRange(_range_name_SBLo, obs_min, blind_min)
             obs.setRange(_range_name_Blind, blind_min, blind_max)
             obs.setRange(_range_name_SBHi, blind_max, obs_max)
@@ -674,7 +677,8 @@ class ExtendedModel(AbstractObject):
         for category in category_map:
             obs_name = category_map[category]['observable']
             obs = self.workspace.var(obs_name)
-            dummy_range = obs.getRange(blind_range_name)
+            _blind_range_name = f"{blind_range_name}_{category}"
+            dummy_range = obs.getRange(_blind_range_name)
             dummy_min = dummy_range.first
             dummy_max = dummy_range.second
             obs_range = obs.getRange()
@@ -1060,6 +1064,10 @@ class ExtendedModel(AbstractObject):
                                           ROOT.RooFit.Import(dataset_map),
                                           ROOT.RooFit.WeightVar(weight_var))
         if do_import:
+            if ws.data(asimov_data_name):
+                self.stdout.warning(f"WARNING: Dataset with name {asimov_data_name} already exists in the "
+                                    "workspace. The newly generated dataset will not overwrite the original "
+                                    "dataset.")
             getattr(ws, "import")(asimov_data)
             self.stdout.info(f'INFO: Generated Asimov Dataset \"{asimov_data_name}\"')
             
@@ -1347,7 +1355,8 @@ class ExtendedModel(AbstractObject):
     def get_collected_distributions(self, current_distributions=True,
                                     datasets:Optional[Union[List[str],List[ROOT.RooDataSet]]]=None,
                                     snapshots:Optional[List[str]]=None,
-                                    n_bins:Optional[Union[Dict, int]]=None):
+                                    n_bins:Optional[Union[Dict, int]]=None,
+                                    n_pdf_bins:Optional[Union[Dict, int]]=None):
         collected_distributions = {}
                 
         if datasets is not None:
@@ -1365,7 +1374,10 @@ class ExtendedModel(AbstractObject):
                     collected_distributions[category][dataset_name] = distributions[category]
 
         if current_distributions:
-            distributions = self.get_distributions(n_bins=n_bins)
+            if n_pdf_bins is not None:
+                distributions = self.get_distributions(n_bins=n_pdf_bins)
+            else:
+                distributions = self.get_distributions(n_bins=n_bins)
             for category in distributions:
                 if category not in collected_distributions:
                     collected_distributions[category] = {}
@@ -1378,7 +1390,10 @@ class ExtendedModel(AbstractObject):
                     exist = self.workspace.loadSnapshot(snapshot)
                     if not exist:
                         raise RuntimeError("snapshot \"{}\" not found in workspace".format(snapshot))
-                    distributions = self.get_distributions(n_bins=n_bins)
+                    if n_pdf_bins is not None:
+                        distributions = self.get_distributions(n_bins=n_pdf_bins)
+                    else:
+                        distributions = self.get_distributions(n_bins=n_bins)
                     for category in distributions:
                         if category not in collected_distributions:
                             collected_distributions[category] = {}
@@ -1390,9 +1405,11 @@ class ExtendedModel(AbstractObject):
     def plot_distributions(self, categories:Optional[List[str]]=None, current_distributions=True, 
                            datasets:Optional[Union[List[str],List[ROOT.RooDataSet]]]=None,
                            snapshots:Optional[Union[List[str], List[ROOT.RooArgSet]]]=None,
-                           n_bins:Optional[Union[Dict, int]]=None, discriminant:Optional[str]=None,
-                           unit:Optional[str]=None, blind:bool=False, show_errorbar:bool=True,
-                           comparison_options:Optional[Dict]=None, save_as:Optional[str]=None, **kwargs):
+                           n_bins:Optional[Union[Dict, int]]=None, n_pdf_bins:Optional[Union[Dict, int]]=None,
+                           discriminant:Optional[str]=None, unit:Optional[str]=None, blind:bool=False,
+                           show_error:bool=True, comparison_options:Optional[Dict]=None,
+                           logx:bool=False, logy:bool=False,
+                           save_as:Optional[str]=None, **kwargs):
         from quickstats.plots import PdfDistributionPlot
         category_map = self.get_category_map()
         if categories is None:
@@ -1402,7 +1419,8 @@ class ExtendedModel(AbstractObject):
                 raise ValueError("category \"{}\" not found in workspace".format(category))
         collected_distributions = self.get_collected_distributions(current_distributions,
                                                                    datasets, snapshots=snapshots,
-                                                                   n_bins=n_bins)
+                                                                   n_bins=n_bins,
+                                                                   n_pdf_bins=n_pdf_bins)
         if save_as is not None:
             from matplotlib.backends.backend_pdf import PdfPages
             pdf = PdfPages(save_as)
@@ -1413,7 +1431,15 @@ class ExtendedModel(AbstractObject):
             all_blind_range = self.get_blind_range()
         else:
             all_blind_range = {}
-
+            
+        dataset_names = []    
+        if datasets is not None:
+            for dataset in datasets:
+                if isinstance(dataset, ROOT.RooDataSet):
+                    dataset_names.append(dataset.GetName())
+                else:
+                    dataset_names.append(dataset)
+                    
         for i, category in enumerate(categories):
             obs_name = category_map[category]['observable']
             if discriminant is None:
@@ -1428,13 +1454,37 @@ class ExtendedModel(AbstractObject):
                 xlabel = f"{xlabel} [{unit}]"
                 ylabel = f"{ylabel} {unit}"
                 
+            if isinstance(n_pdf_bins, dict):
+                _n_pdf_bins = n_pdf_bins.get(category, None)
+            else:
+                _n_pdf_bins = n_pdf_bins
+                
+            if _n_pdf_bins is not None:
+                binning_map = {}
+                for key in collected_distributions[category]:
+                    data = collected_distributions[category][key]
+                    binning_map[key] = data["x"].shape[0]
+                data_binnings = list(set(binning_map.values()) - set([_n_pdf_bins]))
+                if len(data_binnings) == 0:
+                    scale_map = None
+                elif len(data_binnings) == 1:
+                    data_binnings = data_binnings[0]
+                    scale_map = {}
+                    for key in binning_map:
+                        scale_map[key] = binning_map[key] / data_binnings
+                else:
+                    raise RuntimeError("found mixed binnings in the target distributions")
+            else:
+                scale_map = None
+
             blind_range = all_blind_range.get(obs_name, None)
-            
-            plotter = PdfDistributionPlot(collected_distributions[category], 
+            plotter = PdfDistributionPlot(collected_distributions[category],
+                                          scale_map=scale_map,
                                           figure_index=i, **kwargs)
-            ax = plotter.draw(xlabel=xlabel, ylabel=ylabel, 
+            ax = plotter.draw(xlabel=xlabel, ylabel=ylabel,
+                              logx=logx, logy=logy,
                               blind_range=blind_range,
-                              show_errorbar=show_errorbar,
+                              show_error=show_error,
                               comparison_options=comparison_options)
             if pdf is not None:
                 pdf.savefig(bbox_inches="tight")
@@ -1643,4 +1693,4 @@ class ExtendedModel(AbstractObject):
             self.stdout.info(summary_str)
         if save_as is not None:
             with open(save_as, "w") as f:
-                f.write(summary_str)
\ No newline at end of file
+                f.write(summary_str)
