@@ -84,8 +84,8 @@ class ExtendedRFile(AbstractObject):
         else:
             import pandas as pd
             if isinstance(source, pd.DataFrame):
-                from quickstats.interface.root.data_conversion import dataframe2numpydict
-                source = dataframe2numpydict(source)
+                from quickstats.interface.root.data_conversion import dataframe2numpy
+                source = dataframe2numpy(source)
                 self.initialize(source)
             else:
                 raise RuntimeError("invalid source")
@@ -118,15 +118,15 @@ class ExtendedRFile(AbstractObject):
         if self._rdf is None:
             raise RuntimeError("active tree not set")
             
-    def get_Histo1D(self, name:str, n_bin:int, xmin:float, xmax:float, column:str, weight:Optional[str]=None,
+    def get_Histo1D(self, name:str, n_bins:int, xmin:float, xmax:float, column:str, weight:Optional[str]=None,
                     title:Optional[str]=None, pyobject:bool=False, draw:bool=False, draw_option:Optional[str]=None):
         self.validate()
         if title is None:
             title = name
         if weight is None:
-            r_th1_ptr = self.rdf.Histo1D((name, title, n_bin, xmin, xmax), column)
+            r_th1_ptr = self.rdf.Histo1D((name, title, n_bins, xmin, xmax), column)
         else:
-            r_th1_ptr = self.rdf.Histo1D((name, title, n_bin, xmin, xmax), column, weight)
+            r_th1_ptr = self.rdf.Histo1D((name, title, n_bins, xmin, xmax), column, weight)
         r_th1 = r_th1_ptr.GetPtr()
         if draw:
             if draw_option is None:
