@@ -64,7 +64,7 @@ class Likelihood(AnalysisObject):
             pois = ROOT.RooArgSet(self.poi)
         else:
             pois = self.poi
-        
+
         poi_val = self._parse_poi_val(pois, poi_val)
 
         if snapshot_name is None:
@@ -91,11 +91,12 @@ class Likelihood(AnalysisObject):
         if mode == 3:
             # restore initial parameter values after each fit
             self.load_snapshot(snapshot_name)
-            # fix other pois if they are not studied
-            for poi in self.model.pois:
-                poi.setConstant(1)
-            for poi in pois:
-                poi.setConstant(0)            
+            if len(pois) > 0:
+                # fix other pois if they are not studied
+                for poi in self.model.pois:
+                    poi.setConstant(1)
+                for poi in pois:
+                    poi.setConstant(0)            
             self.minimizer.create_nll()
             prefit_nll = self.minimizer.nll.getVal()
             fit_status = self.minimizer.minimize()
