@@ -538,18 +538,19 @@ class SignalModelling(AbstractObject):
                           comparison_options=comparison_options)
         import matplotlib.pyplot as plt
         plt.savefig(outname, bbox_inches="tight")
+        plt.show()
     
     @staticmethod
     def _get_iter_save_paths(fnames:List[str], save_paths:Optional[Union[List[str], str]]=None):
         # do not save
         if save_paths is None:
             return repeat(None)
-        # save by expressionn
+        # save by expression
         elif isinstance(save_paths, str):
             _save_paths = []
             for fname in fnames:
-                basename = os.path.basename(fname)
-                _save_paths.append(fname.format(basename=basename))
+                basename = os.path.splitext(os.path.basename(fname))[0]
+                _save_paths.append(save_paths.format(basename=basename))
             return _save_paths
         # save by explicit paths
         elif isinstance(save_paths, list):
