@@ -23,7 +23,9 @@ class AsimovHandler(AnalysisBase):
                  minimizer_config:Optional[Dict]=None,
                  verbosity:Optional[Union[int, str]]="INFO"):
         super().__init__(ws, poi_name=[], data_name=data_name,
-                         config=minimizer_config, verbosity=verbosity)
+                         config=minimizer_config, verbosity="WARNING")
+        self.title_indent_str = "\t"
+        self.stdout.verbosity = verbosity
         self.range_name = range_name
         self.initialize()
 
@@ -127,7 +129,8 @@ class AsimovHandler(AnalysisBase):
         orig_snapshot = self.core_variables.snapshot()
         config = self.translate_xml_attributes(attributes)
         asimov_name = config['name']
-        title_str = format_delimiter_enclosed_text(f"Operation {asimov_name}", "+")
+        title_str = format_delimiter_enclosed_text(f"Operation {asimov_name}", "+",
+                                                   indent_str=self.title_indent_str)
         self.stdout.info(title_str)
         setup_str = config['setup'].strip()
         if setup_str:
