@@ -2,8 +2,7 @@ import os
 import sys
 import time
 from typing import Optional, Union, Dict, List, Any
-from quickstats import semistaticmethod
-from quickstats.components import AbstractObject
+from quickstats import semistaticmethod, AbstractObject
 from quickstats.concurrent.logging import standard_log
 from quickstats.utils.common_utils import execute_multi_tasks, is_valid_file
 
