@@ -18,7 +18,8 @@ ctype_maps = {
     np.dtype('double'): ctypes.c_double,
     np.dtype('float64'): ctypes.c_double,
     np.dtype('int64'): ctypes.c_int64,
-    np.dtype('int32'): ctypes.c_int32
+    np.dtype('int32'): ctypes.c_int32,
+    np.dtype('uint64'): ctypes.c_uint64
 }
 
 ctype_str_maps = {
@@ -33,6 +34,7 @@ ctype_str_maps = {
     ctypes.c_ushort : "unsigned short",
     ctypes.c_int64 : "long",
     ctypes.c_long : "long",
+    ctypes.c_uint64: "unsigned long long"
 }
 
 py_type_str_maps = {
@@ -55,7 +57,8 @@ np_type_str_maps = {
     np.dtype('double'): "double",
     np.dtype('float64'): "double",
     np.dtype('int64'): "long long",
-    np.dtype('int32'): "int"
+    np.dtype('int32'): "int",
+    np.dtype('uint64'): "unsigned long long"
 }
 
 typecode_to_np_type_maps = {
