@@ -144,13 +144,13 @@ ROOT_MACROS = \
     """
     namespace THistUtils{
         template<typename T>
-        std::vector<double> GetPoissonError(const std::vector<T> data){
+        std::vector<double> GetPoissonError(const std::vector<T> data, const double& nSigma=1){
             Double_t ym, yp;
             auto inst = RooHistError::instance();
             const int data_size = data.size();
             std::vector<double> result(2*data_size);
             for (size_t i = 0; i < data_size; i++){
-                inst.getPoissonInterval(Int_t(data[i] + 0.5), ym, yp, 1);
+                inst.getPoissonInterval(Int_t(data[i] + 0.5), ym, yp, nSigma);
                 result[i] = data[i] - ym;
                 result[data_size + i] = yp - data[i];
             }
