@@ -56,5 +56,6 @@ EXTRA_COLORS = {
 
 QUICKSTATS_PALETTES  = dict(
     darklines=["#000000", "#0019f5", "#377d22", "#ea3423", "#f2a93b", "#7f170e"],
-    default=['#000000', '#F2385A', '#4AD9D9', '#FDC536', '#125125', '#E88EED', '#B68D40']
+    default=['#000000', '#F2385A', '#4AD9D9', '#FDC536', '#125125', '#E88EED', '#B68D40'],
+    hist_series=['#99CCFF', '#EFCF6E', '#64CB34']
 )
\ No newline at end of file
