@@ -3,14 +3,23 @@ from typing import Optional, Union, Dict, List
 import matplotlib.patches as patches
 import matplotlib.lines as lines
 import pandas as pd
-import ROOT
 
 from quickstats.plots import AbstractPlot
 from quickstats.plots.template import single_frame, parse_styles
-from quickstats.utils.roostats_utils import get_array_quantiles
 
 class HypoTestInverterPlot(AbstractPlot):
     
+    STYLES = {
+        'axis':{
+            'tick_bothsides': False
+        },
+        'errorbar': {
+            "linewidth": 1,
+            "markersize": 5,
+            "marker": 'o',
+        }        
+    }    
+    
     COLOR_PALLETE = {
         '2sigma': '#FDC536',
         '1sigma': '#4AD9D9',
@@ -21,7 +30,7 @@ class HypoTestInverterPlot(AbstractPlot):
     
     def __init__(self, result, nsig:int=2, 
                  color_pallete:Optional[Dict]=None,
-                 styles:Optional[Union[Dict, str]]='limit',
+                 styles:Optional[Union[Dict, str]]=None,
                  analysis_label_options:Optional[Dict]=None):
         self.result = result
         
@@ -30,6 +39,7 @@ class HypoTestInverterPlot(AbstractPlot):
                          analysis_label_options=analysis_label_options)
         
     def get_expected_CLs_data(self):
+        from quickstats.utils.roostats_utils import get_array_quantiles
         n_entries = self.result.ArraySize()
         data = {}
         for i in range(n_entries):
