@@ -22,6 +22,12 @@ class Likelihood2DPlot(AbstractPlot):
             'color': '#E9F1DF',
             'markeredgecolor': 'black'
         },
+        'bestfit_styles':{
+            'marker': 'P',
+            'linewidth': 0,
+            'markersize': 15
+        },
+        'bestfit_label': "Best fit ({x}, {y})",
         'cmap': 'GnBu',
         'interpolation': 'cubic',
         'num_grid_points': 100,
@@ -107,19 +113,19 @@ class Likelihood2DPlot(AbstractPlot):
                         linestyles=linestyles, linewidths=3)
         if clabel_size is not None:
             ax.clabel(cp, inline=True, fontsize=clabel_size)
-        custom_handles = [Line2D([0], [0], color=color, linestyle=linestyle, lw=3, label=label) for color, key, label, linestyle in zip(
-            config['sigma_colors'], config['sigma_levels'], config['sigma_names'], config['sigma_linestyles'])]
+        custom_handles = [Line2D([0], [0], color=color, linestyle=linestyle, lw=3, label=label) \
+                          for color, key, label, linestyle in \
+                          zip(config['sigma_colors'], config['sigma_levels'], config['sigma_names'], config['sigma_linestyles'])]
         self.update_legend_handles(
             dict(zip(config['sigma_names'], custom_handles)))
         self.legend_order.extend(config['sigma_names'])
-        ax.legend(handles=custom_handles, **self.styles['legend'])
-
         return custom_handles
 
     def draw(self, xattrib: str, yattrib: str, zattrib: str = 'qmu', xlabel: Optional[str] = "",
              ylabel: Optional[str] = "", zlabel: Optional[str] = "$-2\Delta ln(L)$",
              ymax: float = 5, ymin: float = -5, xmin: Optional[float] = -10, xmax: Optional[float] = 10,
-             clabel_size=None, draw_sm_line: bool = False, show_colormesh=False):
+             clabel_size=None, draw_sm_line: bool = False, draw_bestfit:bool=True,
+             show_colormesh=False):
         ax = self.draw_frame()
         if isinstance(self.data_map, pd.DataFrame):
             self.draw_single_data(ax, self.data_map, xattrib=xattrib, yattrib=yattrib,
@@ -138,7 +144,7 @@ class Likelihood2DPlot(AbstractPlot):
                 config_map = {k: k for k in self.data_map}
             else:
                 config_map = self.config_map
-            handles = {}
+                
             for key in self.data_map:
                 data = self.data_map[key]
                 styles = styles_map.get(key, None)
@@ -151,17 +157,28 @@ class Likelihood2DPlot(AbstractPlot):
                                                zattrib=zattrib,
                                                styles=styles,
                                                config=config,
-                                               show_colormesh=show_colormesh
-                                               )
-                handles[key] = handle
-            # self.update_legend_handles(handles)
-
+                                               show_colormesh=show_colormesh)
         else:
             raise ValueError("invalid data format")
-
+        
+        highlight_index = 0
+        
+        if draw_bestfit and isinstance(self.data_map, pd.DataFrame):
+            bestfit_idx = self.data_map[[zattrib]].idxmin()
+            bestfit_x   = self.data_map[xattrib].iloc[bestfit_idx].values[0]
+            bestfit_y   = self.data_map[yattrib].iloc[bestfit_idx].values[0]
+            highlight_data = {
+                'x': bestfit_x,
+                'y': bestfit_y,
+                'label': self.config["bestfit_label"].format(x=bestfit_x, y=bestfit_y),
+                'styles': self.config["bestfit_styles"]
+            }
+            self.draw_highlight(ax, highlight_data, highlight_index)
+            highlight_index += 1
+        
         if self.highlight_data is not None:
             for i, h in enumerate(self.highlight_data):
-                self.draw_highlight(ax, h, i)
+                self.draw_highlight(ax, h, highlight_index + i)
 
         if draw_sm_line:
             sm_line_styles = self.config['sm_line_styles']
